<!-- Index page
  Copyright (C) 2020  Đào Dương Hoàng Long
  Copyright (C) 2020  Nguyễn Gia Phong

  This file is part of Acanban.

  Acanban is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published
  by the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Acanban is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with Acanban.  If not, see <https://www.gnu.org/licenses/>.
-->

{% extends "base.html" %}
{% block title %}Acanban{% endblock %}
{% block content %}
{% if current_user.is_authenticated %}
<div class=col-wide>Welcome, {{ current_user.name }}!</div>
{% else %}
<div class=col-wide>
  <p>Acanban is an academic Kanban board.  It aims to provide
     a collaboration platform for students and mentors,
     with first-class support for academic evaluation.</p>
  <img src="/static/collaboration.svg" alt="Drawing of people collaborating">
</div>
{% endif %}
{% endblock %}
